@@ -26,15 +26,15 @@ from sqlalchemy import asc, desc, func, select
 
 from airflow.api_connexion.exceptions import AlreadyExists, BadRequest, NotFound
 from airflow.api_connexion.parameters import check_limit, format_parameters
-from airflow.api_connexion.schemas.role_and_permission_schema import (
+from airflow.api_connexion.security import requires_access_custom_view
+from airflow.providers.fab.auth_manager.models import Action, Role
+from airflow.providers.fab.auth_manager.schemas.role_and_permission_schema import (
     ActionCollection,
     RoleCollection,
     action_collection_schema,
     role_collection_schema,
     role_schema,
 )
-from airflow.api_connexion.security import requires_access_custom_view
-from airflow.providers.fab.auth_manager.models import Action, Role
 from airflow.providers.fab.auth_manager.security_manager.override import FabAirflowSecurityManagerOverride
 from airflow.security import permissions
 from airflow.www.extensions.init_auth_manager import get_auth_manager
@@ -77,8 +77,8 @@ def get_roles(*, order_by: str = "name", limit: int, offset: int | None = None)
     to_replace = {"role_id": "id"}
     order_param = order_by.strip("-")
     order_param = to_replace.get(order_param, order_param)
-    allowed_filter_attrs = ["role_id", "name"]
-    if order_by not in allowed_filter_attrs:
+    allowed_sort_attrs = ["role_id", "name"]
+    if order_by not in allowed_sort_attrs:
         raise BadRequest(
             detail=f"Ordering with '{order_by}' is disallowed or "
             f"the attribute does not exist on the model"
